@@ -2,7 +2,6 @@ from aflowey.f import (
     F,
 )
 from aflowey.functions import (
-    async_wrap,
     ensure_callable,
     side_effect,
     may_fail,
@@ -16,7 +15,7 @@ from aflowey.functions import (
     F1,
     erratic,
     breaker,
-    lift,
+    partial,
     imp,
     impure,
     apartial,
@@ -24,6 +23,7 @@ from aflowey.functions import (
     identity,
     log,
     flog,
+    lift,
 )
 from aflowey.async_flow import (
     AsyncFlow,
@@ -34,6 +34,10 @@ from aflowey.executor import (
     AsyncFlowExecutor,
     async_exec,
     aexec,
+    run_flows,
+    flows_from_arg,
+    spawn_flows,
+    astarmap,
 )
 
 from aflowey.single_executor import (
@@ -42,7 +46,6 @@ from aflowey.single_executor import (
 
 __all__ = [
     "F",
-    "async_wrap",
     "ensure_callable",
     "side_effect",
     "f0",
@@ -52,7 +55,7 @@ __all__ = [
     "erratic",
     "breaker",
     "may_fail",
-    "lift",
+    "partial",
     "imp",
     "impure",
     "AsyncFlow",
@@ -71,4 +74,9 @@ __all__ = [
     "CANCEL_FLOW",
     "flog",
     "log",
+    "run_flows",
+    "flows_from_arg",
+    "spawn_flows",
+    "astarmap",
+    "lift",
 ]
